@@ -30,7 +30,6 @@ from plone.event.interfaces import IEvent
 from plone.event.interfaces import IEventAccessor
 from plone.event.interfaces import IOccurrence
 from plone.event.interfaces import IRecurrenceSupport
-from plone.testing.z2 import Browser
 from plone.uuid.interfaces import IUUID
 from zope.annotation.interfaces import IAnnotations
 
@@ -39,6 +38,13 @@ import pytz
 import unittest
 import zope.interface
 
+try:
+    # plone.testing 7+
+    from plone.testing.zope import Browser
+except ImportError:
+    # plone.testing 6-
+    from plone.testing.z2 import Browser
+
 
 TEST_TIMEZONE = "Europe/Vienna"
 
